% Load and format session 1 data
session1 = readtable('../../session1.csv');
session1.correct = strcmp(session1.chosen, session1.correct);
session1.chosen = string(session1.chosen);
session1.chosen = str2double(extract(session1.chosen, digitsPattern));
session1.id = string(session1.id);

% Load and format session 2 data
session2 = readtable('../../session2.csv');
session2.correct = strcmp(session2.chosen, session2.correct);
session2.chosen = string(session2.chosen);
session2.chosen = str2double(extract(session2.chosen, digitsPattern));
session2.id = string(session2.id);

% Load exclusion data
exclude = readtable('../../exclude.csv');
exclude.id = string(exclude.id);


% Prepare output structure
D = struct('SubID', {}, 'R', {}, 'A', {}, 'Nch', {}, 'C', {}, 'trialfirstses', {}, 'outlier', {});
% Get IDs
ids = unique(vertcat(session1.id, session2.id));

for i = 1:length(ids)
    id = ids(i);
    ses1 = session1(session1.id == id, :);
    ses2 = session2(session2.id == id, :);

    D(i).SubID = id;
    D(i).R = vertcat(ses1.outcome, ses2.outcome)';
    D(i).A = vertcat(ses1.chosen, ses2.chosen)';
    D(i).Nch = height(ses1) + height(ses2);
    D(i).C = vertcat(ses1.correct, ses2.correct)';
    D(i).trialsfirstses = height(ses1);

    if sum(contains(exclude.id, ids(i))) > 0
        D(i).outlier = 1;
    else
        D(i).outlier = 0;
    end

end

save('data/RL_Data_Retest_for_modeling_wo', 'D')


%Prepare data for R studio
for_r = cell2table(cell(0,7), 'VariableNames', {'SubID','Session','correct','stay','pfb','persev','RT'});
for i = 1:length(ids)
    id = ids(i);
    ses1 = session1(session1.id == id, :); ses2 = session2(session2.id == id, :);
    ses1.pfb = circshift(ses1.outcome, 1); ses2.pfb = circshift(ses2.outcome, 1);
    ses1.pfb(1) = nan; ses2.pfb(1) = nan;
    ses1.correct_choice(:) = nan; ses2.correct_choice(:) = nan;
    ses1.persev(:) = 0; ses2.persev(:) = 0;
    %find where the first reversal occurs
    for ii = 1:length(ses1.id)
        if ses1.correct(ii) == 0
            ses1.correct_choice(ii) = (ses1.chosen(ii)* -1) + 3;
        else
            ses1.correct_choice(ii) = ses1.chosen(ii);
        end
    end

    for ii = 1:length(ses2.id)
        if ses2.correct(ii) == 0
            ses2.correct_choice(ii) = (ses2.chosen(ii)* -1) + 3;
        else
            ses2.correct_choice(ii) = ses2.chosen(ii);
        end
    end

    ses1.chosen_lag = circshift(ses1.chosen, 1); 
    ses2.chosen_lag = circshift(ses2.chosen, 1);
    ses1.chosen_lag(1) = nan; ses2.chosen_lag(1) = nan;
    ses1.stay = ses1.chosen == ses1.chosen_lag;
    ses2.stay = ses2.chosen == ses2.chosen_lag;
    
    ses1.correct_choice_lag = circshift(ses1.correct_choice, 1); 
    ses2.correct_choice_lag = circshift(ses2.correct_choice, 1);
    ses1.correct_choice_lag(1) = nan; ses2.correct_choice_lag(1) = nan;

    ses1.reversal = ((ses1.correct_choice == ses1.correct_choice_lag) -1)*-1;
    ses1.reversal(1) = 0;
    ses2.reversal = ((ses2.correct_choice == ses2.correct_choice_lag) -1)*-1;
    ses2.reversal(1) = 0;
    ses1.reversal_num = cumsum(ses1.reversal);
    ses2.reversal_num = cumsum(ses2.reversal); 

    for ii = 1:length(ses1.id)
        if ses1.reversal_num(ii) >= 1
            if ses1.reversal_num(ii) ~= ses1.reversal_num(ii-1)
                fresh = 2;
            end

            if ses1.chosen(ii) ~= ses1.correct_choice(ii)
                if fresh == 0
                    ses1.persev(ii) = 1;
                end
            end
            
            if ses1.chosen(ii) ~= ses1.correct_choice(ii)
                if ses1.outcome(ii) == -1
                    if fresh ~= 0
                        fresh = fresh -1;
                    end
                end
            end
        end
    end

    for ii = 1:length(ses2.id)
        if ses2.reversal_num(ii) >= 1
            if ses2.reversal_num(ii) ~= ses2.reversal_num(ii-1)
                fresh = 2;
            end

            if ses2.chosen(ii) ~= ses2.correct_choice(ii)
                if fresh == 0
                    ses2.persev(ii) = 1;
                end
            end
            
            if ses2.chosen(ii) ~= ses2.correct_choice(ii)
                if ses2.outcome(ii) == -1
                    if fresh ~= 0
                        fresh = fresh -1;
                    end
                end
            end
        end
    end

    ses1.Session(:) = 1;
    ses2.Session(:) = 2;
    ses1.SubID = ses1.id;
    ses2.SubID = ses2.id;
    ses1.RT = ses1.rt;
    ses2.RT = ses2.rt;
    for_r = [for_r; ses1(:,["SubID","Session","correct","stay","pfb","persev","RT"])];
    for_r = [for_r; ses2(:,["SubID","Session","correct","stay","pfb","persev","RT"])];
    



end

for i = 1:height(exclude)
    sub = exclude.id(i);
    for_r(for_r.SubID == sub, :) = [];
end
writetable(for_r, 'data/RL_Data_Retest_R_wo.txt')
