library(reshape2)
library(tidyverse)
library(ggplot2)
library(dplyr)
library(data.table)
library(reshape2)
library(colorspace)
library(stringr)
library(plot.matrix)
library(effectsize)

# Load data and reshape into long format
boot <- read.csv("varcomps_modelling.csv")
boot_normalised <- boot
boot_normalised$within <- abs(boot_normalised$within) / (abs(boot_normalised$within) + abs(boot_normalised$between) + abs(boot_normalised$error))
boot_normalised$between <- abs(boot_normalised$between) / (abs(boot_normalised$within) + abs(boot_normalised$between) + abs(boot_normalised$error))
boot_normalised$error <- abs(boot_normalised$error) / (abs(boot_normalised$within) + abs(boot_normalised$between) + abs(boot_normalised$error))
boot <- boot_normalised
boot <- melt(boot, id.vars = c("n","iteration","variable","icc"), variable.name = "varcomp")
boot$varcomp <- as.numeric(factor(boot$varcomp, levels = c("within", "error", "between")))


# Set names for labelling figures
variable_names <- c("Reinforcement sensitivity for wins",
                    "Reinforcement sensitivity for losses",
                    "Learning rate")
variance_names <- c("Within-subject", "Error", "Between-subject")
list <- lapply(1:length(variance_names), function(i){
  variance_names[i]
  list <- lapply(1:length(variable_names), function(ii){
    subdata <- subset(boot, variable == ii & varcomp == i)
    # set columns as factors
    factors <- c("n")
    subdata[factors] <- lapply(subdata[factors], factor)
    tmp <- aov(value ~ n, data = subdata)
    tmp.posthoc <- pairwise.t.test(subdata$value, subdata$n, p.adjust.method = "holm")$p.value
    par(mar = c(4.2, 4.2, 1.5, 1))
    png(str_interp("${variance_names[i]} ${variable_names[ii]}.png"), width = 2250, height = 2000, units = "px", res = 300)
    plot(as.pvalue(tmp.posthoc), border = NA, digits = NA, reorder = F, xlab = "Sample size", ylab = "Sample size", col = c("#7469B6","#AD88C6","#E1AFD1","#FFE6E6","#FFE6E6"), axis.col=list(at = c(1,16,41,66,91,116,141,166,191,216,241,266,289), labels = c(10,25,50,75,100,125,150,175,200,225,250,275,"")), axis.row = list(las = 1, at = c(289,275,250,225,200,175,150,125,100,75,50,25,1), labels = c(11,25,50,75,100,125,150,175,200,225,250,275,"")), spacing.key=10, axes = F, main = str_interp("${variable_names[ii]}"), key = NULL)
    dev.off()
    effectsizes <- eta_squared(tmp)$Eta2
    tmp <- summary(tmp)
    tmp[[1]]$eta2 <- c(effectsizes, NA)
    write.csv(tmp[[1]],str_interp("${variance_names[i]} ${variable_names[ii]}_aov.csv"))
    write.csv(tmp.posthoc,str_interp("${variance_names[i]} ${variable_names[ii]}_posthoc.csv"))
    tmp[[1]]
  })
  names(list) <- variable_names
  data.table::rbindlist(list, idcol ="variable")
})
names(list) <- variance_names
within <- list$`Within-subject`
within$variance <- "Within-subject"
within$effect <- rep(c("n","Residuals"), length(variable_names))

between <- list$`Between-subject`
between$variance <- "Between-subject"
between$effect <- rep(c("n","Residuals"), length(variable_names))

error <- list$Error
error$variance <- "Error"
error$effect <- rep(c("n","Residuals"), length(variable_names))

anovas_df <- rbind(within, between)
anovas_df <- rbind(anovas_df, error)


#anovas_df <- melt(anovas_df, id.vars = c("variance","effect","eta2"), variable.name = "variable", value.name = "p.null")
anovas_df <- anovas_df[!is.na(anovas_df$`Pr(>F)`),]


anovas_df$pstat_sign <- case_when(anovas_df$`Pr(>F)` >= (0.05 / (length(variance_names)*length(variable_names))) ~ "=",
                                  anovas_df$`Pr(>F)` < (0.05 / (length(variance_names)*length(variable_names))) ~ sprintf("\u2731"))
anovas_df$variance <- factor(anovas_df$variance, levels = unique(anovas_df$variance), labels = c("Within-subject","Between-subject","Error"))
anovas_df$effect <- factor(anovas_df$effect, levels = unique(anovas_df$effect), labels = c("Sample size"))


ggplot(anovas_df, aes(x=effect, y=variable, fill=eta2)) +
  geom_raster() +
  geom_text(aes(label = pstat_sign), colour = "white", size = 6, fontface = "bold") +
  scale_fill_gradientn(name = "Effect size",
                       trans = "log10",
                       breaks = c(0, 0.01, 0.06, 0.14),
                       colours = sequential_hcl(10, palette = "Sunset"),
                       values = scales::rescale(log10(c(min(anovas_df$eta2), 0.01, 0.06, 0.14, max(anovas_df$eta2))))) +
  facet_wrap("variance") +
  theme_minimal() +
  theme(text = element_text(size = 20), axis.title = element_blank()) +
  theme(legend.title = element_text(size = 16), legend.key.height = unit(2, "lines")) +
  theme(axis.text.x = element_text(angle = 270, hjust=0))
ggsave("revisions_parameter-anova-overview_figure.png", bg = "white", height = 4.5, width=10.1)
